@@ -24,6 +24,7 @@
 
 #include "config.h"
 #include "gchemtable-app.h"
+#include <libgnomevfs/gnome-vfs-init.h>
 #include <goffice/goffice.h>
 #include <goffice/app/go-plugin.h>
 #include <goffice/app/go-plugin-loader-module.h>
@@ -32,12 +33,9 @@ using namespace gcu;
 
 int main (int argc, char *argv[])
 {
-	bindtextdomain (GETTEXT_PACKAGE, DATADIR"/locale");
-#ifdef ENABLE_NLS
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-#endif
 	textdomain (GETTEXT_PACKAGE);
 	gtk_init (&argc, &argv);
+	gnome_vfs_init ();
 	/* Initialize libgoffice */
 	libgoffice_init ();
 	/* Initialize plugins manager */
